==> gq_0.5.0.orig.tar.gz: gq-0.5.0.orig/src/debug.c <==
/*
    GQ -- a GTK-based LDAP client
    Copyright (C) 1998-2001 Bert Vermeulen

    This program is released under the Gnu General Public License with
    the additional exemption that compiling, linking, and/or using
    OpenSSL is allowed.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


#include <stdio.h>

#include "debug.h"
#include "configfile.h"
#include "common.h"

int num_mallocs = 0;
int max_mallocs = 0;

extern struct gq_config config;


void *gq_malloc(size_t size, char *msg)
{

     void *newmem;

     newmem = malloc(size);
     printf("+ gq_malloc: %s (%d bytes @ 0x%x)\n", msg, size,
	    (unsigned int) newmem);

     num_mallocs++;
     max_mallocs++;

     return(newmem);
}


void gq_free(void *mem, char *msg)
{

     printf("- gq_free: %s (0x%x)\n", msg, (unsigned int) mem);
     num_mallocs--;

     free(mem);

}


void report_num_mallocs(void)
{

     printf("==============================================\n");
     printf("Total number of mallocs: %d\n", max_mallocs);
     printf("Number of mallocs left : %d\n", num_mallocs);

     if(num_mallocs)
	  printf("memory allocation mismatch: %d allocations left\n",
		 num_mallocs);

}


void dump_ldapservers(void)
{
     struct ldapserver *server;
     int i;

     i = 1;
     server = config.ldapservers;
     while(server) {
	  printf("server %d: %s\n", i, server->name);
	  server = server->next;
	  i++;
     }

}

==> gq-0.6.0.tar.gz: gq-0.6.0/src/debug.c <==
/*
    GQ -- a GTK-based LDAP client
    Copyright (C) 1998-2001 Bert Vermeulen

    This program is released under the Gnu General Public License with
    the additional exemption that compiling, linking, and/or using
    OpenSSL is allowed.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* $Id: debug.c,v 1.4 2002/06/09 15:24:20 stamfest Exp $ */

#include <stdio.h>
#include "debug.h"
#include "configfile.h"
#include "common.h"

int num_mallocs = 0;
int max_mallocs = 0;


void *gq_malloc(size_t size, char *msg)
{

     void *newmem;

     newmem = malloc(size);
     printf("+ gq_malloc: %s (%d bytes @ 0x%x)\n", msg, size,
	    (unsigned int) newmem);

     num_mallocs++;
     max_mallocs++;

     return(newmem);
}


void gq_free(void *mem, char *msg)
{

     printf("- gq_free: %s (0x%x)\n", msg, (unsigned int) mem);
     num_mallocs--;

     free(mem);

}


void report_num_mallocs(void)
{

     printf("==============================================\n");
     printf("Total number of mallocs: %d\n", max_mallocs);
     printf("Number of mallocs left : %d\n", num_mallocs);

     if(num_mallocs)
	  printf("memory allocation mismatch: %d allocations left\n",
		 num_mallocs);

}


void dump_ldapservers(void)
{
     struct ldapserver *server;
     int i;

     i = 1;
     server = config.ldapservers;
     while(server) {
	  printf("server %d: %s\n", i, server->name);
	  server = server->next;
	  i++;
     }

}




#if 0

void hexdump_plain(unsigned char *p, int n)
{
     int i;

     for (i = 0 ; i < n ; i++, p++) {
	  printf("%c", isprint(*p) ? *p : '.');
     }
}

void hexdump(char *msg, unsigned char *p, int n)
{
     int i;
     unsigned char *d = p;

     printf("%s %08lx\n", msg, (long) p);

     for (i = 0 ; i < n ; i++, p++) {
	  printf("%02x ", *p);
	  if (i % 16 == 15) {
	       printf("   ");
	       hexdump_plain(d, 16);
	       d = p; d++;
	       printf("\n");
	  }
     }
     if (i % 16 != 0) {
	  hexdump_plain(d, 16);
	  d = p; d++;
	  printf("\n");
     }
}

#endif

#ifdef MEMDEBUG
#ifdef HAVE_MALLINFO
static int memstat_timeout_id = -1;
static int memstat_activity = 0;
static char *memstat_act = "-/|\\";

static gint memstat_timer(gpointer data)
{
    struct mallinfo info = mallinfo();
    printf("\rin_use/alloc %9d/%9d [%c]", info.uordblks, info.arena,
	   memstat_act[memstat_activity++]);

    if (!memstat_act[memstat_activity])
	memstat_activity = 0;

    fflush(stdout);
    return TRUE;
}


void init_memstat_timer() {
    if (memstat_timeout_id == -1) {
	memstat_timeout_id = gtk_timeout_add(500, memstat_timer, NULL);
    }
}
#endif /* HAVE_MALLINFO */
#endif /* MEMDEBUG */
